@@ -13,20 +13,27 @@ from reactivex.operators import flat_map, share
 from reactivex.scheduler import ThreadPoolScheduler
 from reactivex.subject import BehaviorSubject
 
-from bittrade_cryptodotcom_websocket import (
+from ..models import (
     CryptodotcomResponseMessage,
     EnhancedWebsocket,
     EnhancedWebsocketBehaviorSubject,
+)
+
+from ..operators import (
     exclude_response_messages,
     keep_messages_only,
     keep_new_socket_only,
     keep_response_messages_only,
+)
+from ..connection import (
     private_websocket_connection,
     public_websocket_connection,
+)
+from ..channels import (
     subscribe_open_orders,
     subscribe_order_book,
 )
-from bittrade_cryptodotcom_websocket.rest import (
+from ..rest import (
     cancel_all_factory,
     cancel_all_http_factory,
     cancel_order_factory,
@@ -41,6 +48,7 @@ from ..models import BookConfig, CryptodotcomContext
 
 logger = getLogger(__name__)
 
+
 def get_framework(
     add_token: Callable[
         [Observable[CryptodotcomResponseMessage]],
@@ -48,7 +56,7 @@ def get_framework(
     ],
     add_token_http: Callable[[requests.models.Request], requests.models.Request],
     books: Optional[tuple[BookConfig]] = None,
-    load_markets=True
+    load_markets=True,
 ) -> CryptodotcomContext:
     books = books or cast(tuple[BookConfig], ())
     exchange = cryptocom()
